@@ -1,13 +1,13 @@
 package OpenInteract::FullText;
 
-# $Id: FullText.pm,v 1.8 2001/02/01 05:26:04 cwinters Exp $
+# $Id: FullText.pm,v 1.2 2001/02/04 23:07:55 lachoy Exp $
 
 use strict;
 use Lingua::Stem ();
 use DBI          qw( SQL_VARCHAR SQL_INTEGER );
 use Data::Dumper qw( Dumper );
 
-$OpenInteract::FullText::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::FullText::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 @OpenInteract::FullText::ISA     = ();
 
 my %STOPWORDS = map { $_ => 1 } qw/
@@ -51,7 +51,7 @@ sub create_class_index {
 # $p->{search_terms} is an arrayref of terms
 # $p->{search_type} is 'any' (OR -- the default) or 'all' (AND)
 # $p->{include_classes} \% of classes to use (and only these)
-# $pe->{exclude_classes} \% of classes NOT to use
+# $p->{exclude_classes} \% of classes NOT to use
 
 sub search_ft_index {
   my ( $class, $p ) = @_;
@@ -88,6 +88,7 @@ sub search_ft_index {
     my $num_removed = map { delete $results->{ $_ } } 
                       grep { scalar keys %{ $results->{ $_ } } < $num_terms } 
                       keys %{ $results };
+    $R->scrib( 1, "Removed ($num_removed) items from the list since they didn't match all the terms" );
   }
 
   # @object_list keeps the objects constructed from the results
@@ -216,6 +217,7 @@ sub reindex_object {
   my $R = OpenInteract::Request->instance;
   $R->scrib( 1, "Trying to index ", ref $self, " (", $self->id, ")" );
   my $indexable = $self->_indexable_object_text;
+  $R->scrib( 2, "Indexable text: ", $indexable );
   my $wc = $self->_tokenize( $indexable );
   $R->scrib( 2, "Found the following tokens:", Dumper( $wc ) );
  
@@ -247,8 +249,14 @@ sub remove_object_from_index {
 # one big field
 
 sub _indexable_object_text {
-  return undef unless ( ref $_[0]->CONFIG->{fulltext_field} eq 'ARRAY' );
-  return join ' ', map { $_[0]->{$_} } @{ $_[0]->CONFIG->{fulltext_field} };
+  my ( $self ) = @_;
+  my $R = OpenInteract::Request->instance;
+  my $field_list = $self->CONFIG->{fulltext_field};
+  unless ( ref $field_list eq 'ARRAY' ) {
+    $R->scrib( 0, "Cannot index object text -- no fields presented in config file." );
+    return undef;
+  }
+  return join ' ', map { $self->{$_} } @{ $field_list };
 }
 
 
@@ -283,7 +291,7 @@ sub _store_terms {
 
   my $count = 0;
   foreach my $term ( keys %{ $terms } ) {
-    $R->scrib( 1, "Storing $ft_oid: $term ($terms->{$term})" );
+    $R->scrib( 2, "Storing $ft_oid: $term ($terms->{$term})" );
     eval {
       $sth->bind_param( 1, $term, SQL_VARCHAR );
       $sth->bind_param( 2, $ft_oid, SQL_VARCHAR );
@@ -323,23 +331,26 @@ OpenInteract::FullText - Metadata layer for objects to implement simple full-tex
  # In object's spops.perl file
  myobj => {
   isa => [ qw/ OpenInteract::FullText ... / ],
-  fulltext_fields => [ qw/ description title / ],
+  fulltext_field => [ qw/ description title / ],
   ...
  }
 
+ # All 'save()' calls to the object will trigger the object's
+ # 'description' and 'title' fields being indexed.
+
 =head1 DESCRIPTION
 
 This module implements a few simple rules, along with some
-implementation goop, that allow objects to be full-text indexed, only
-changing a few lines in the configuration file. By putting this module
-in the @ISA (done through the configuration file) of a SPOPS data
-object, that object can then call methods to index itself, and calls
-to search the index can return instances of that object.
+implementation goop, that allow objects to be full-text indexed just
+by changing a few lines in the configuration file. By putting this
+module in the @ISA (done through the configuration file) of a SPOPS
+data object, that object can then call methods to index itself, and
+calls to search the index can return instances of that object.
 
 The design of this module should make it simple to swap out various
 text indexing solutions, so objects can treat full-text indexing as a
-black box -- some boxes give better results than others, but they all
-take the same inputs and give the same outputs.
+black box -- some boxes give better (or different) results than
+others, but they all take the same inputs and give the same outputs.
 
 =head1 METHODS
 
@@ -348,6 +359,8 @@ B<create_class_index()>
 Initialize a class into the index by retrieving all of its objects and
 calling the I<reindex_object> method on each (see below).
 
+Currently you can call this from the command line 
+
 B<ruleset_add( $class, \%ruleset_table )>
 
 Adds the necessary rules to the $class that puts this class in its
@@ -459,33 +472,21 @@ B<_ft_search_terms( \%params )>
 Performs the actual search, putting the results into an intermediate
 format. Returns a hashref with the keys as object identifiers and the
 values a hashref of stemmed terms with the number of ocurrences of
-each term as the value there. For instance:
+each term as the value there. For instance, doing a search for
+'congress' and 'senate' might bring up:
 
-  $oid = { 'OpenInteract::News||44' => { congress => 2, senate => 3 },
-           'OpenInteract::BasicPage||/toolkit/congress' => { congress => 8, senate => 1 },
+  $oid = { 'OpenInteract::News||44' => { congress => 2, 
+                                         senate => 3 },
+           'OpenInteract::BasicPage||/toolkit/congress' => { congress => 8, 
+                                                             senate => 1 },
            ... 
   };
 
-=head1 NOTES
-
 =head1 TO DO
 
-B<Flexibility in Storage>
-
-Allow different types of storage for the index -- see
-L<DBIx::FullTextSearch> -- but ensure that database portability is
-kept in mind.
-
-B<Flexibility in Searching>
-
-Allow proximity searches, phrase searches, explicit scoring, wildcard
-specification, boolean operators.
-
-B<Weighted Parsing>
-
-Words in headlines or the title should be "worth" more than normal
-terms -- maybe increase the hit count for them? (Such as: a term if
-found in a title is worth 1.5 matches.)
+See the TO DO list in the documentation found in this package. (Under
+'doc/' in the package distribution, or via the system documentation
+available through the OpenInteract browser interface.)
 
 =head1 BUGS
 
