@@ -1,6 +1,6 @@
 package OpenInteract::Handler::BasicPage;
 
-# $Id: BasicPage.pm,v 1.19 2001/02/01 05:26:28 cwinters Exp $
+# $Id: BasicPage.pm,v 1.3 2001/02/06 22:10:42 lachoy Exp $
 
 use strict;
 use SPOPS::Secure  qw( :level );
@@ -9,7 +9,7 @@ use Data::Dumper   qw( Dumper );
 use File::Basename qw();
 
 @OpenInteract::Handler::BasicPage::ISA     = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure  );
-$OpenInteract::Handler::BasicPage::VERSION = sprintf("%d.%02d", q$Revision: 1.19 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::BasicPage::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::BasicPage::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::BasicPage::default_method    = 'listing';
@@ -156,6 +156,16 @@ sub show {
 
     unless ( $page_info or $do_edit ) {
       $R->scrib( 1, "Creating new page or empty page info. Error type: ($error_type)" );
+
+      # We have to force the content-type here because the user might
+      # have requested a file that actually exists in the filesystem
+      # and which Apache has already mapped a content-type. You'll
+      # know when this happens because you'll be prompted to d/l the
+      # file or a plugin (like Acrobat Reader) will try to display it,
+      # but the *actual* content will be plain old HTML...
+
+      $R->{page}->{content_type} = 'text/html';
+
       if ( $error_type =~ /^security/ ) {
         return "<h2>Access Forbidden</h2>" .
                "<p>You do not have access rights to view this page. " .
@@ -447,10 +457,18 @@ sub _fetch_file {
     # Pull out the title, main template, author, extra boxes (if they
     # exist)
     
-    ( $page_info->{title} ) = $page_info->{pagetext} =~ s/<title>(.*)?<\/title>//;
-    ( $page_info->{main_template} ) = $page_info->{pagetext} =~ s/<template>(.*)?<\/template>//;
-    ( $page_info->{author} ) = $page_info->{pagetext} =~ s/<author>(.*)?<\/author>//;
-    ( $page_info->{boxes} ) = $page_info->{pagetext} =~ s/<boxes>(.*)?<\/boxes>//;
+    if ( $page_info->{pagetext} =~ s|<title>(.*)?</title>|| ) {
+      $page_info->{title}    = $1;
+    }
+    if ( $page_info->{pagetext} =~ s|<template>(.*)?</template>|| ) {
+      $page_info->{main_template} = $1;
+    }
+    if ( $page_info->{pagetext} =~ s|<author>(.*)?</author>|| ) {
+      $page_info->{author}   = $1;
+    }
+    if ( $page_info->{pagetext} =~ s|<boxes>(.*)?</boxes>|| ) {
+      $page_info->{boxes}    = $1;
+    }
     
     # Only use the information between the $BODY_DEMARCATION tags (if they exist)
     
