@@ -1,6 +1,6 @@
 package OpenInteract::Handler::Box;
 
-# $Id: Box.pm,v 1.2 2001/02/01 05:24:35 cwinters Exp $
+# $Id: Box.pm,v 1.2 2001/02/04 23:08:49 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
@@ -32,6 +32,15 @@ sub process_boxes {
   my $system_box_class = $R->CONFIG->{box}->{system_box_handler};
   $system_box_class->handler();
 
+  my $custom_box_class = $R->CONFIG->{box}->{custom_box_handler};
+  if ( $custom_box_class ) {
+    eval { $custom_box_class->handler() };
+    if ( $@ ) {
+      $R->scrib( 0, "Cannot call custom box handler: $custom_box_class. Error: $@" );
+    }
+  }
+  
+
   # Next, weed out boxes without at least a name; assign a default
   # weight of 5 as necessary and weed out those with a weight > 100
 
