@@ -1,20 +1,19 @@
 package OpenInteract::Handler::Package;
 
-# $Id: Package.pm,v 1.11 2001/02/01 05:24:32 cwinters Exp $
+# $Id: Package.pm,v 1.2 2001/02/20 04:14:28 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 use Data::Dumper  qw( Dumper );
 
 @OpenInteract::Handler::Package::ISA               = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure );
-$OpenInteract::Handler::Package::VERSION           = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Package::VERSION           = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::Handler::Package::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Package::default_method    = 'listing';
 @OpenInteract::Handler::Package::forbidden_methods = ();
-$OpenInteract::Handler::Package::select_tab        = { main => 'interact', group => 'members' };
 %OpenInteract::Handler::Package::security          = ( 
- listing => SEC_LEVEL_READ,  show => SEC_LEVEL_WRITE,    
- edit => SEC_LEVEL_WRITE,    remove => SEC_LEVEL_WRITE,
+ listing => SEC_LEVEL_READ,  show   => SEC_LEVEL_WRITE,    
+ edit    => SEC_LEVEL_WRITE, remove => SEC_LEVEL_WRITE,
 );
 
 use constant DEBUG => 1;
@@ -31,19 +30,20 @@ sub listing {
 
   # First retrieve the packages from this app
 
-  my %local_pkg = map { $_->id => $_ } 
-                     @{ $R->package->fetch_group({ directory => $R->CONFIG->{dir}->{base} }) };
-  foreach my $pkg_id ( sort keys %local_pkg ) {
-    push @{ $params->{website_pkg} }, $local_pkg{ $pkg_id };
-  }
+  my $website_dir = $R->CONFIG->{dir}->{base};
+  $R->scrib( 1, "Trying to open repository in website dir ($website_dir)" );
+  my $website_repository  = $R->repository->fetch( 
+                                     undef, { directory => $website_dir } );
+  $params->{website_pkg}  = $website_repository->fetch_all_packages();
 
-  # Next, retrieve the packages from interact
+  # Next, retrieve the packages from base installation
 
-  my %interact_pkg = map { $_->id => $_ } 
-                     @{ $R->package->fetch_group({ directory => $R->CONFIG->{dir}->{interact} }) };
-  foreach my $pkg_id ( sort keys %interact_pkg ) {
-    push @{ $params->{interact_pkg} }, $interact_pkg{ $pkg_id };
-  }
+  my $base_install_dir = $R->CONFIG->{dir}->{interact};
+  $R->scrib( 1, "Trying to open repository in base installation dir ($base_install_dir)" );
+  my $base_repository     = $R->repository->fetch( 
+                                     undef, { directory => $base_install_dir } );
+  $params->{interact_pkg} = $base_repository->fetch_all_packages();
+  $R->{page}->{title} = "Package Listing";
   return $R->template->handler( {}, $params, 
                                 { db => 'package_listing', package => 'base' } );
 }
@@ -62,12 +62,13 @@ sub show {
   my $base_dir = ( $params->{scope} eq 'interact' ) 
                    ? $R->CONFIG->{dir}->{interact} 
                    : $R->CONFIG->{dir}->{base};
+  my $repository = $R->repository->fetch( undef, { directory => $base_dir } );
+
   my $name    = $R->apache->param( 'name' );
   my $version = $R->apache->param( 'version' );
   my $pkg = $p->{pkg} || 
-            $R->package->fetch_by_name({ directory => $base_dir, 
-                                         name => $name, 
-                                         version => $version });
+            $repository->fetch_package_by_name({ name => $name, 
+                                                 version => $version });
   unless ( $pkg ) {
     my $error_msg = "Sorry, couldn't find a package matching the criteria you specified.";
     return $class->listing( { error_msg => $error_msg } );
@@ -76,7 +77,8 @@ sub show {
     $params->{error_msg} .= "Found a working package, but it wasn't the version you requested.";
   }
   $params->{pkg} = $pkg;
-  return $R->template->handler( {}, $params, { db => 'package_detail', package => 'base' } );
+  return $R->template->handler( {}, $params, { db => 'package_detail', 
+                                               package => 'base' } );
 }
 
 sub edit {
@@ -87,12 +89,13 @@ sub edit {
   my $version = $R->apache->param( 'version' );
   my $scope   = $R->apache->param( 'scope' );
   my $base_dir = ( $scope eq 'interact' ) ? $R->CONFIG->{dir}->{interact} : $R->CONFIG->{dir}->{base};
-  my $db_file = join( '/', $base_dir, $OpenInteract::Package::PKG_DB_FILE );
-  my $pkg = $R->package->fetch_by_name({ name => $name, 
-                                         version => $version,
-                                         directory => $base_dir });
-  if ( $@ or $pkg ) {
-    my $error = $@ || "no package found using $name - $version";
+  my $repository = $R->repository->fetch( undef, { directory => $base_dir,
+                                                   perm      => 'write' } );
+  
+  my $pkg = $repository->fetch_package_by_name({ name => $name, 
+                                                 version => $version });
+  if ( $@ or ! $pkg ) {
+    my $error = $@ || "No package found using $name-$version";
     my $error_msg = "No changes made; cannot retrieve package for editing. Error: $error";
     return $class->listing( { error_msg => $error_msg } );
   }
@@ -100,9 +103,10 @@ sub edit {
   foreach my $field ( @editable_fields ) {
     $pkg->{ $field } = $R->apache->param( $field );
   }
-  $pkg->{last_updated_on} = $pkg->now;
-  $pkg->{last_updated_by} = $R->{auth}->{user}->{user_id};
-  eval { $pkg->save };
+  $pkg->{last_updated_on} = $repository->now;
+  $pkg->{last_updated_by} = join( ' ', $R->{auth}->{user}->{login_name}, "<$R->{auth}->{user}->{email}>" );
+  $repository->save_package( $pkg );
+  eval { $repository->save() };
   if ( $@ ) {
     $params->{error_msg} = "Cannot save package changes! Error returned: $@";
   }
@@ -112,7 +116,11 @@ sub edit {
 
 sub remove {
  my ( $class, $p ) = @_;
- return $class->listing({ error_msg => 'Sorry, removal of packages is not supported yet.' });
+ my $msg = <<MSG;
+Sorry, removal of packages is not supported yet. Please use the 
+command line interface provided by <code>oi_manage</code>.
+MSG
+ return $class->listing({ error_msg =>  });
 }
 
 1;
