@@ -1,25 +1,26 @@
 package OpenInteract::Handler::SiteSearch;
 
-# $Id: SiteSearch.pm,v 1.8 2001/02/01 05:26:06 cwinters Exp $
+# $Id: SiteSearch.pm,v 1.2 2001/02/04 23:07:55 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
+use OpenInteract::FullText;
 
 @OpenInteract::Handler::SiteSearch::ISA               = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::SiteSearch::VERSION           = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::SiteSearch::VERSION           = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::Handler::SiteSearch::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::SiteSearch::default_method    = 'search';
 @OpenInteract::Handler::SiteSearch::forbidden_methods = ();
-$OpenInteract::Handler::SiteSearch::select_tab        = { main => 'interact', group => 'members' };
-
 
+# Pretty straightforward...
 
 sub search {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
   my $keywords = $R->apache->param( 'keywords' );
   unless ( $keywords ) {
-    return '<h2>Cannot Search</h2><p>Search called without keywords and cannot run. ' .
+    return '<h2>Cannot Search</h2>',
+           '<p>Search called without keywords and cannot run. ' .
            'Please <a href="/search/home">try again</a>.';
   }
 
