@@ -2,7 +2,7 @@ CREATE TABLE theme (
  theme_id      %%INCREMENT%%,
  title         varchar(50) not null,
  description   text null,
- parent        %%INCREMENT_TYPE%% not null,
+ parent        int not null,
  credit        varchar(200) null,
  primary key   ( theme_id )
 )
